@@ -1,10 +1,3 @@
-
-param <- define_parameters(
-  a = 1,
-  b = 4 * markov_cycle,
-  c = a + b
-)
-
 mat <- define_matrix(
   state_names = c("s1", "s2"),
   1 / c, 1 - 1/ c,
@@ -21,7 +14,6 @@ s2 <- define_state(
   )
 
 define_model(
-  parameters = param,
   transition_matrix = mat,
   s1 = s1,
   s2 = s2
